@@ -28,7 +28,7 @@ dependencies using raw pip. The virtual environment is not created, but one can
 issue `python3 -m venv venv/ && . venv/bin/activate` to create one.
 """
 
-__version__ = "1.1.2"
+__version__ = "1.1.3"
 __author__ = "Fridolin Pokorny <fridex.devel@gmail.com>"
 __title__ = "micropipenv"
 
@@ -48,7 +48,7 @@ from pathlib import Path
 from urllib.parse import urlparse
 
 _LOGGER = logging.getLogger(__title__)
-_SUPPORTED_PIP_STR = ">=9,<=21.2.4"  # Respects requirement in setup.py and latest pip to release date.
+_SUPPORTED_PIP_STR = ">=9,<=21.3"  # Respects requirement in setup.py and latest pip to release date.
 
 try:
     from pip import __version__ as pip_version
@@ -91,6 +91,7 @@ if TYPE_CHECKING:
     from typing import List
     from typing import MutableMapping
     from typing import Optional
+    from typing import Sequence
     from typing import Tuple
     from typing import Union
     from pip._internal.req.req_file import ParsedRequirement
@@ -834,32 +835,40 @@ def install_requirements(pip_bin=_PIP_BIN, *, pip_args=None):  # type: (str, Opt
         _maybe_print_pip_freeze(pip_bin)
 
 
+def method_discovery(ignore_files=None):  # type: (Optional[Sequence[str]]) -> str
+    """Find the best method to use according to dependencies definition."""
+    ignore_files = ignore_files if ignore_files else tuple()
+    files = [f for f in _FILE_METHOD_MAP.keys() if f not in ignore_files]
+    paths = []
+    for file_name in files:
+        try:
+            paths.append(Path(_traverse_up_find_file(file_name)))
+        except FileNotFound:
+            pass
+
+    if not paths:
+        raise FileNotFound(
+            "Failed to find {} "
+            "in the current directory or any of its parent: {!r}".format(" or ".join(files), os.getcwd())
+        )
+
+    _LOGGER.debug("Dependencies definitions found: %s", paths)
+    # The longest path means that we are as close to CWD as possible.
+    # Sorting is also stable which means that two paths with the same
+    # lenght will have the same order when sorted which keeps priorities
+    # from _FILE_METHOS_MAP.
+    longest_path = sorted(paths, key=lambda p: len(p.parts), reverse=True)[0]
+    _LOGGER.debug("Choosen definition: %s", str(longest_path))
+
+    return _FILE_METHOD_MAP[longest_path.name]
+
+
 def install(
     method=None, *, pip_bin=_PIP_BIN, deploy=False, dev=False, pip_args=None
 ):  # type: (Optional[str], str, bool, bool, Optional[List[str]]) -> None
     """Perform installation of requirements based on the method used."""
     if method is None:
-        paths = []
-        for file_name in _FILE_METHOD_MAP.keys():
-            try:
-                paths.append(Path(_traverse_up_find_file(file_name)))
-            except FileNotFound:
-                pass
-
-        if not paths:
-            raise FileNotFound(
-                "Failed to find Pipfile.lock, poetry.lock or requirements.txt "
-                "in the current directory or any of its parent: {}".format(os.getcwd())
-            )
-
-        _LOGGER.debug("Dependencies definitions found: %s", paths)
-        # The longest path means that we are as close to CWD as possible.
-        # Sorting is also stable which means that two paths with the same
-        # lenght will have the same order when sorted which keeps priorities
-        # from _FILE_METHOS_MAP.
-        longest_path = sorted(paths, key=lambda p: len(p.parts), reverse=True)[0]
-        _LOGGER.debug("Choosen definition: %s", str(longest_path))
-        method = _FILE_METHOD_MAP[longest_path.name]
+        method = method_discovery()
 
     if method == "requirements":
         if deploy:
@@ -1088,7 +1097,7 @@ def requirements_str(
 
 
 def requirements(
-    method="pipenv",
+    method=None,
     sections=None,
     *,
     no_hashes=False,
@@ -1098,8 +1107,11 @@ def requirements(
     no_default=False,
     no_dev=False,
     no_comments=False,
-):  # type: (str, Optional[Dict[str, Any]], bool, bool, bool, bool, bool, bool, bool) -> None
+):  # type: (Optional[str], Optional[Dict[str, Any]], bool, bool, bool, bool, bool, bool, bool) -> None
     """Show requirements of an application, the output generated is compatible with pip-tools."""
+    if method is None:
+        method = method_discovery(ignore_files=("requirements.txt",))
+
     if method == "pipenv":
         sections = sections or get_requirements_sections(
             no_indexes=no_indexes, only_direct=only_direct, no_default=no_default, no_dev=no_dev
